from Products.CMFCore.utils import getToolByName
from Products.Archetypes.Extensions.utils import installTypes, install_subskin
from Products.Archetypes.public import listTypes
from Products.SimpleAttachment.config import GLOBALS, PROJECTNAME
from StringIO import StringIO

def install(self):
    out = StringIO()

    # Install types
    classes = listTypes(PROJECTNAME)
    installTypes(self, out, classes, PROJECTNAME)
    print >> out, "Installed types"

    # Install skin
    install_subskin(self, out, GLOBALS)
    print >> out, "Installed skin"

    # Set up the workflow for the widget types
    setupFileAttachmentWorkflow(self)
    setupImageAttachmentWorkflow(self)
    print >> out, "Set up FileAttachment and ImageAttachment workflows."

    # Make the widget types use the /view action when linked to
    setupFileAttachmentView(self)
    setupImageAttachmentView(self)
    print >> out, "Set up FileAttachment and ImageAttachment to use /view."

    propsTool = getToolByName(self, 'portal_properties')
    siteProperties = getattr(propsTool, 'site_properties')
    navtreeProperties = getattr(propsTool, 'navtree_properties')

    # Add the FileAttachment and ImageAttachment types to types_not_searched
    # (this is configurable via the Search settings control panel)
    typesNotSearched = list(siteProperties.getProperty('types_not_searched'))
    if 'FileAttachment' not in typesNotSearched:
        typesNotSearched.append('FileAttachment')
    if 'ImageAttachment' not in typesNotSearched:
        typesNotSearched.append('ImageAttachment')
    siteProperties.manage_changeProperties(types_not_searched = typesNotSearched)
    print >> out, "Added FileAttachment and ImageAttachment to types_not_searched"

    # Add FileAttachment and ImageAttachment to kupu's linkable and media types
    kupuTool = getToolByName(self, 'kupu_library_tool')
    linkable = list(kupuTool.getPortalTypesForResourceType('linkable'))
    mediaobject = list(kupuTool.getPortalTypesForResourceType('mediaobject'))
    if 'FileAttachment' not in linkable:
        linkable.append('FileAttachment')
    if 'ImageAttachment' not in linkable:
        linkable.append('ImageAttachment')
    if 'ImageAttachment' not in mediaobject:
        mediaobject.append('ImageAttachment')
    # kupu_library_tool has an idiotic interface, basically written purely to
    # work with its configuration page. :-(
    kupuTool.updateResourceTypes(({'resource_type' : 'linkable',
                                   'old_type'      : 'linkable',
                                   'portal_types'  :  linkable},
                                  {'resource_type' : 'mediaobject',
                                   'old_type'      : 'mediaobject',
                                   'portal_types'  :  mediaobject},))
    print >> out, "Added FileAttachment and ImageAttachment to kupu's linkable and mediaobject types"

    return out.getvalue()


def setupImageAttachmentWorkflow(context):
    """Turn off workflow for the ImageAttachment type. Should be called 
    with a context parameter that allows portal_workflow to be acquired.
    """
    wft = getToolByName(context, 'portal_workflow')
    wft.setChainForPortalTypes(('ImageAttachment',), ())


def setupImageAttachmentView(context):
    """Add ImageAttachment to the list of types which use the /view suffix in
    listings. Should be called with a context parameter that allows
    portal_workflow to be acquired.
    """
    propsTool = getToolByName(context, 'portal_properties')
    siteProperties = getattr(propsTool, 'site_properties')
    typesUseViewActionInListings = list(siteProperties.getProperty('typesUseViewActionInListings'))
    if 'ImageAttachment' not in typesUseViewActionInListings:
        typesUseViewActionInListings.append('ImageAttachment')
    siteProperties.manage_changeProperties(typesUseViewActionInListings  = typesUseViewActionInListings)


def setupFileAttachmentWorkflow(context):
    """Turn off workflow for the FileAttachment type. Should be called with
    a context parameter that allows portal_workflow to be acquired.
    """
    wft = getToolByName(context, 'portal_workflow')
    wft.setChainForPortalTypes(('FileAttachment',), ())

def setupFileAttachmentView(context):
    """Add FileAttachment to the list of types which use the /view suffix in
    listings. Should be called with a context parameter that allows
    portal_workflow to be acquired.
    """
    propsTool = getToolByName(context, 'portal_properties')
    siteProperties = getattr(propsTool, 'site_properties')
    typesUseViewActionInListings = list(siteProperties.getProperty('typesUseViewActionInListings'))
    if 'FileAttachment' not in typesUseViewActionInListings:
        typesUseViewActionInListings.append('FileAttachment')
    siteProperties.manage_changeProperties(typesUseViewActionInListings  = typesUseViewActionInListings)

